InverseMedianRank
=================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: InverseMedianRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~InverseMedianRank.increasing
      ~InverseMedianRank.name
      ~InverseMedianRank.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~InverseMedianRank.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
